==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/is/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Asset Categories',
    'category_name'  					=> 'Heiti Vöruflokks',
    'checkin_email'                     => 'Senda tölvupóst til notenda til að skrá sig inn / út.',
    'checkin_email_notification'        => 'Þessi notandi fær tölvupóst til að skrá sig inn/út.',
    'clone'                             => 'Afrita Vöruflokk',
    'create'  							=> 'Stofna vöruflokk',
    'edit'                              => 'Breyta vöruflokk',
    'eula_text'							=> 'Vöruflokkur fyrir notendaskilmála',
    'eula_text_help'					=> 'Þessi reitur gerir þér kleift að sérsníða notendaskilmála fyrir ákveðinn búnað. Ef þú hefur aðeins einn notendaskilmála fyrir allan þinn búnað þá skaltu haka í reitinn fyrir neðan sem notar sömu skilmálana fyrir allann þann búnað.',
    'name'                              => 'Heiti vöruflokks',
    'require_acceptance'				=> 'Kerfjast þess að notendur samþykki viðtöku búnaðs í þessum flokki.',
    'required_acceptance'				=> 'Þessi notandi fær töluvpóst með hlekk til að staðfesta móttöku á þessum hlut.',
    'required_eula'						=> 'Þessi notandi fær tölvupóst með notendaskilmálum',
    'no_default_eula'					=> 'Fann enga sjálfgefna notendaskilmála. Vinsamlegast bættu þeim við í undir "Stillingar"',
    'update'  							=> 'Breyta vöruflokk',
    'use_default_eula'					=> 'Notaðu frekar <a href="#" data-toggle="modal" data-target="#eulaModal">',
    'use_default_eula_disabled'			=> '<del>Notaðu frekar sjálfgefna notendaskilmálana.</del>Sjálfgefnu notendaskilmálarnir eru ekki í notkun. Vinsamlegast bættu einhverjum notendaskilmálum við í undir "Stillingar"',

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/is/admin/categories/general.php <==
<?php

return array(
    'asset_categories' 					=> 'Eignaflokkar',
    'category_name'  					=> 'Heiti Vöruflokks',
    'checkin_email'                     => 'Senda tölvupóst til notenda til að skrá sig inn / út.',
    'checkin_email_notification'        => 'Þessi notandi fær tölvupóst til að skrá sig inn/út.',
    'clone'                             => 'Afrita Vöruflokk',
    'create'  							=> 'Stofna vöruflokk',
    'edit'                              => 'Breyta vöruflokk',
    'eula_text'							=> 'Vöruflokkur fyrir notendaskilmála',
    'eula_text_help'					=> 'Þessi reitur gerir þér kleift að sérsníða notendaskilmála fyrir ákveðinn búnað. Ef þú hefur aðeins einn notendaskilmála fyrir allan þinn búnað þá skaltu haka í reitinn fyrir neðan sem notar sömu skilmálana fyrir allann þann búnað.',
    'name'                              => 'Heiti vöruflokks',
    'require_acceptance'				=> 'Kerfjast þess að notendur samþykki viðtöku búnaðs í þessum flokki.',
    'required_acceptance'				=> 'Þessi notandi fær töluvpóst með hlekk til að staðfesta móttöku á þessum hlut.',
    'required_eula'						=> 'Þessi notandi fær tölvupóst með notendaskilmálum',
    'no_default_eula'					=> 'Fann enga sjálfgefna notendaskilmála. Vinsamlegast bættu þeim við í undir "Stillingar"',
    'update'  							=> 'Breyta vöruflokk',
    'use_default_eula'					=> 'Notaðu frekar <a href="#" data-toggle="modal" data-target="#eulaModal">',
    'use_default_eula_disabled'			=> '<del>Notaðu frekar sjálfgefna notendaskilmálana.</del>Sjálfgefnu notendaskilmálarnir eru ekki í notkun. Vinsamlegast bættu einhverjum notendaskilmálum við í undir "Stillingar"',
    'use_default_eula_column'			=> 'Use default EULA',

);
